﻿using System;
using System.Security.Cryptography;
using System.Text;
using System.Threading;
using System.Windows;
using System.Windows.Controls;
using WBBExternalLogin;
using WBBExternalLogin.ServerResponse;

namespace WBBExternalLoginExample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        //In diesem Beispiel ist ein Login demonstriert.
        //Wir möchten nur Benutzer zulassen, die mehr als 40 Beiträge haben.
        private async void Button_Click_1(object sender, RoutedEventArgs e)
        {
            Login forum = new Login(new Uri(UrlBox.Text));
            LoginResponse response = await forum.PerformLoginAsync(UsernameBox.Text, GetSHA1Hash(PasswordBox.Password));
            if (response.Code == (int)Code.Success)
            {
                //Sofern der Login überhaupt erfolgreich war. 
                //Diese Prüfung sollte immer erfolgen, denn bei einem fehlgeschlagegenen Login ist Data null bzw. Nothing.
                if (response.Data.Posts >= 40)
                {
                    MessageBox.Show("Der Login war korrekt, der Benutzer ist nicht gebannt und hat mehr als 40 Beiträge.");
                }
            }
            else
                MessageBox.Show(((Code)response.Code).ToString());
        }

        private void Button_Click_2(object sender, RoutedEventArgs e)
        {
            var username = UsernameBox.Text;
            var password = GetSHA1Hash(PasswordBox.Password);

            Login forum = new Login(new Uri(UrlBox.Text));
            forum.LoginCompleted += forum_LoginCompleted; //Event setzen
            var t = new Thread(() => forum.PerformLogin(username, password));
            t.Start();
        }

        private void forum_LoginCompleted(object sender, Login.LoginCompletedEventArgs e)
        {
            if (e.Response.Code == (int)Code.Success)
            {
                //Sofern der Login überhaupt erfolgreich war. 
                //Diese Prüfung sollte immer erfolgen, denn bei einem fehlgeschlagegenen Login ist Data null bzw. Nothing.
                if (e.Response.Data.Posts >= 40)
                {
                    //Data enthält neben den Posts auch die userID und nochmals den Benutzernamen.
                    //Ebenso die Gruppen des Benutzers. So kann z.B. kontrolliert werden, ob ein Benutzer Administrator ist.
                    MessageBox.Show("Der Login war korrekt, der Benutzer ist nicht gebannt und hat mehr als 40 Beiträge.");
                }
            }
            else
                MessageBox.Show(((Code)e.Response.Code).ToString());
        }

        public static string GetSHA1Hash(string text)
        {
            var SHA1 = new SHA1CryptoServiceProvider();

            string result = null;

            byte[] arrayData = Encoding.ASCII.GetBytes(text);
            byte[] arrayResult = SHA1.ComputeHash(arrayData);
            for (int i = 0; i < arrayResult.Length; i++)
            {
                string temp = Convert.ToString(arrayResult[i], 16);
                if (temp.Length == 1)
                    temp = "0" + temp;
                result += temp;
            }
            return result;
        }
    }
}